Class: Google::Apis::ServicecontrolV1::AuthorizationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

Authorization information for the operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthorizationInfo

Returns a new instance of AuthorizationInfo.



574
575
576
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 574

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#grantedBoolean Also known as: granted?

Whether or not authorization for resource and permission was granted. Corresponds to the JSON property granted

Returns:

  • (Boolean)


539
540
541
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 539

def granted
  @granted
end

#permissionString

The required IAM permission. Corresponds to the JSON property permission

Returns:

  • (String)


545
546
547
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 545

def permission
  @permission
end

#permission_typeString

The type of the permission that was checked. For data access audit logs this corresponds with the permission type that must be enabled in the project/ folder/organization IAM policy in order for the log to be written. Corresponds to the JSON property permissionType

Returns:

  • (String)


552
553
554
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 552

def permission_type
  @permission_type
end

#privileged_access_manager_metadataGoogle::Apis::ServicecontrolV1::PrivilegedAccessManagerMetadata

Metadata about the Privileged Access Manager (PAM) backed authorization decisions. Corresponds to the JSON property privilegedAccessManagerMetadata



558
559
560
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 558

def 
  @privileged_access_manager_metadata
end

#resourceString

The resource being accessed, as a REST-style or cloud resource string. For example: bigquery.googleapis.com/projects/PROJECTID/datasets/DATASETID or projects/PROJECTID/datasets/DATASETID Corresponds to the JSON property resource

Returns:

  • (String)


565
566
567
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 565

def resource
  @resource
end

#resource_attributesGoogle::Apis::ServicecontrolV1::Resource

This message defines core attributes for a resource. A resource is an addressable (named) entity provided by the destination service. For example, a file stored on a network storage service. Corresponds to the JSON property resourceAttributes



572
573
574
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 572

def resource_attributes
  @resource_attributes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



579
580
581
582
583
584
585
586
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 579

def update!(**args)
  @granted = args[:granted] if args.key?(:granted)
  @permission = args[:permission] if args.key?(:permission)
  @permission_type = args[:permission_type] if args.key?(:permission_type)
  @privileged_access_manager_metadata = args[:privileged_access_manager_metadata] if args.key?(:privileged_access_manager_metadata)
  @resource = args[:resource] if args.key?(:resource)
  @resource_attributes = args[:resource_attributes] if args.key?(:resource_attributes)
end