Class: Google::Apis::ServicecontrolV1::CheckInfo
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::CheckInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
Contains additional information about the check operation.
Instance Attribute Summary collapse
-
#api_key_uid ⇒ String
The unique id of the api key in the format of "apikey:".
-
#consumer_info ⇒ Google::Apis::ServicecontrolV1::ConsumerInfo
ConsumerInfoprovides information about the consumer. -
#ignore_api_key_uid_as_credential_id ⇒ Boolean
(also: #ignore_api_key_uid_as_credential_id?)
Whether or not the api key should be ignored in the credential_id during reporting.
-
#unused_arguments ⇒ Array<String>
A list of fields and label keys that are ignored by the server.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CheckInfo
constructor
A new instance of CheckInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CheckInfo
Returns a new instance of CheckInfo.
663 664 665 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 663 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_key_uid ⇒ String
The unique id of the api key in the format of "apikey:". This field will be
populated when the consumer passed to Chemist is an API key and all the API
key related validations are successful.
Corresponds to the JSON property apiKeyUid
642 643 644 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 642 def api_key_uid @api_key_uid end |
#consumer_info ⇒ Google::Apis::ServicecontrolV1::ConsumerInfo
ConsumerInfo provides information about the consumer.
Corresponds to the JSON property consumerInfo
647 648 649 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 647 def consumer_info @consumer_info end |
#ignore_api_key_uid_as_credential_id ⇒ Boolean Also known as: ignore_api_key_uid_as_credential_id?
Whether or not the api key should be ignored in the credential_id during
reporting.
Corresponds to the JSON property ignoreApiKeyUidAsCredentialId
653 654 655 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 653 def ignore_api_key_uid_as_credential_id @ignore_api_key_uid_as_credential_id end |
#unused_arguments ⇒ Array<String>
A list of fields and label keys that are ignored by the server. The client
doesn't need to send them for following requests to improve performance and
allow better aggregation.
Corresponds to the JSON property unusedArguments
661 662 663 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 661 def unused_arguments @unused_arguments end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
668 669 670 671 672 673 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 668 def update!(**args) @api_key_uid = args[:api_key_uid] if args.key?(:api_key_uid) @consumer_info = args[:consumer_info] if args.key?(:consumer_info) @ignore_api_key_uid_as_credential_id = args[:ignore_api_key_uid_as_credential_id] if args.key?(:ignore_api_key_uid_as_credential_id) @unused_arguments = args[:unused_arguments] if args.key?(:unused_arguments) end |