Class: Google::Apis::ServicecontrolV1::CheckRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

Request message for the Check method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CheckRequest

Returns a new instance of CheckRequest.



706
707
708
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationGoogle::Apis::ServicecontrolV1::Operation

Represents information regarding an operation. Corresponds to the JSON property operation



683
684
685
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 683

def operation
  @operation
end

#request_project_settingsBoolean Also known as: request_project_settings?

Requests the project settings to be returned as part of the check response. Corresponds to the JSON property requestProjectSettings

Returns:

  • (Boolean)


688
689
690
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 688

def request_project_settings
  @request_project_settings
end

#service_config_idString

Specifies which version of service configuration should be used to process the request. If unspecified or no matching version can be found, the latest one will be used. Corresponds to the JSON property serviceConfigId

Returns:

  • (String)


696
697
698
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 696

def service_config_id
  @service_config_id
end

#skip_activation_checkBoolean Also known as: skip_activation_check?

Indicates if service activation check should be skipped for this request. Default behavior is to perform the check and apply relevant quota. WARNING: Setting this flag to "true" will disable quota enforcement. Corresponds to the JSON property skipActivationCheck

Returns:

  • (Boolean)


703
704
705
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 703

def skip_activation_check
  @skip_activation_check
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



711
712
713
714
715
716
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 711

def update!(**args)
  @operation = args[:operation] if args.key?(:operation)
  @request_project_settings = args[:request_project_settings] if args.key?(:request_project_settings)
  @service_config_id = args[:service_config_id] if args.key?(:service_config_id)
  @skip_activation_check = args[:skip_activation_check] if args.key?(:skip_activation_check)
end