Class: Google::Apis::ServicecontrolV1::FirstPartyPrincipal
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::FirstPartyPrincipal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
First party identity principal.
Instance Attribute Summary collapse
-
#principal_email ⇒ String
The email address of a Google account.
-
#service_metadata ⇒ Hash<String,Object>
Metadata about the service that uses the service account.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirstPartyPrincipal
constructor
A new instance of FirstPartyPrincipal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirstPartyPrincipal
Returns a new instance of FirstPartyPrincipal.
958 959 960 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 958 def initialize(**args) update!(**args) end |
Instance Attribute Details
#principal_email ⇒ String
The email address of a Google account. .
Corresponds to the JSON property principalEmail
951 952 953 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 951 def principal_email @principal_email end |
#service_metadata ⇒ Hash<String,Object>
Metadata about the service that uses the service account. .
Corresponds to the JSON property serviceMetadata
956 957 958 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 956 def @service_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
963 964 965 966 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 963 def update!(**args) @principal_email = args[:principal_email] if args.key?(:principal_email) @service_metadata = args[:service_metadata] if args.key?(:service_metadata) end |