Class: Google::Apis::ServicecontrolV1::LogEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

An individual log entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogEntry

Returns a new instance of LogEntry.



1256
1257
1258
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1256

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#http_requestGoogle::Apis::ServicecontrolV1::HttpRequest

A common proto for logging HTTP requests. Only contains semantics defined by the HTTP specification. Product-specific logging information MUST be defined in a separate message. Corresponds to the JSON property httpRequest



1188
1189
1190
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1188

def http_request
  @http_request
end

#insert_idString

A unique ID for the log entry used for deduplication. If omitted, the implementation will generate one based on operation_id. Corresponds to the JSON property insertId

Returns:

  • (String)


1194
1195
1196
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1194

def insert_id
  @insert_id
end

#labelsHash<String,String>

A set of user-defined (key, value) data that provides additional information about the log entry. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1200
1201
1202
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1200

def labels
  @labels
end

#nameString

Required. The log to which this log entry belongs. Examples: "syslog", " book_log". Corresponds to the JSON property name

Returns:

  • (String)


1206
1207
1208
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1206

def name
  @name
end

#operationGoogle::Apis::ServicecontrolV1::LogEntryOperation

Additional information about a potentially long-running operation with which a log entry is associated. Corresponds to the JSON property operation



1212
1213
1214
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1212

def operation
  @operation
end

#proto_payloadHash<String,Object>

The log entry payload, represented as a protocol buffer that is expressed as a JSON object. The only accepted type currently is AuditLog. Corresponds to the JSON property protoPayload

Returns:

  • (Hash<String,Object>)


1218
1219
1220
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1218

def proto_payload
  @proto_payload
end

#severityString

The severity of the log entry. The default value is LogSeverity.DEFAULT. Corresponds to the JSON property severity

Returns:

  • (String)


1223
1224
1225
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1223

def severity
  @severity
end

#source_locationGoogle::Apis::ServicecontrolV1::LogEntrySourceLocation

Additional information about the source code location that produced the log entry. Corresponds to the JSON property sourceLocation



1229
1230
1231
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1229

def source_location
  @source_location
end

#struct_payloadHash<String,Object>

The log entry payload, represented as a structure that is expressed as a JSON object. Corresponds to the JSON property structPayload

Returns:

  • (Hash<String,Object>)


1235
1236
1237
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1235

def struct_payload
  @struct_payload
end

#text_payloadString

The log entry payload, represented as a Unicode string (UTF-8). Corresponds to the JSON property textPayload

Returns:

  • (String)


1240
1241
1242
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1240

def text_payload
  @text_payload
end

#timestampString

The time the event described by the log entry occurred. If omitted, defaults to operation start time. Corresponds to the JSON property timestamp

Returns:

  • (String)


1246
1247
1248
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1246

def timestamp
  @timestamp
end

#traceString

Optional. Resource name of the trace associated with the log entry, if any. If this field contains a relative resource name, you can assume the name is relative to //tracing.googleapis.com. Example: projects/my-projectid/traces/ 06796866738c859f2f19b7cfb3214824 Corresponds to the JSON property trace

Returns:

  • (String)


1254
1255
1256
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1254

def trace
  @trace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1261

def update!(**args)
  @http_request = args[:http_request] if args.key?(:http_request)
  @insert_id = args[:insert_id] if args.key?(:insert_id)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @operation = args[:operation] if args.key?(:operation)
  @proto_payload = args[:proto_payload] if args.key?(:proto_payload)
  @severity = args[:severity] if args.key?(:severity)
  @source_location = args[:source_location] if args.key?(:source_location)
  @struct_payload = args[:struct_payload] if args.key?(:struct_payload)
  @text_payload = args[:text_payload] if args.key?(:text_payload)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
  @trace = args[:trace] if args.key?(:trace)
end