Class: Google::Apis::ServicecontrolV1::MetricValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

Represents a single metric value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetricValue

Returns a new instance of MetricValue.



1419
1420
1421
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

A boolean value. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


1365
1366
1367
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1365

def bool_value
  @bool_value
end

#distribution_valueGoogle::Apis::ServicecontrolV1::Distribution

Distribution represents a frequency distribution of double-valued sample points. It contains the size of the population of sample points plus additional optional information: * the arithmetic mean of the samples * the minimum and maximum of the samples * the sum-squared-deviation of the samples, used to compute variance * a histogram of the values of the sample points Corresponds to the JSON property distributionValue



1375
1376
1377
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1375

def distribution_value
  @distribution_value
end

#double_valueFloat

A double precision floating point value. Corresponds to the JSON property doubleValue

Returns:

  • (Float)


1380
1381
1382
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1380

def double_value
  @double_value
end

#end_timeString

The end of the time period over which this metric value's measurement applies. If not specified, google.api.servicecontrol.v1.Operation.end_time will be used. Corresponds to the JSON property endTime

Returns:

  • (String)


1386
1387
1388
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1386

def end_time
  @end_time
end

#int64_valueFixnum

A signed 64-bit integer value. Corresponds to the JSON property int64Value

Returns:

  • (Fixnum)


1391
1392
1393
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1391

def int64_value
  @int64_value
end

#labelsHash<String,String>

The labels describing the metric value. See comments on google.api. servicecontrol.v1.Operation.labels for the overriding relationship. Note that this map must not contain monitored resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1398
1399
1400
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1398

def labels
  @labels
end

#money_valueGoogle::Apis::ServicecontrolV1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property moneyValue



1403
1404
1405
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1403

def money_value
  @money_value
end

#start_timeString

The start of the time period over which this metric value's measurement applies. The time period has different semantics for different metric types ( cumulative, delta, and gauge). See the metric definition documentation in the service configuration for details. If not specified, google.api.servicecontrol. v1.Operation.start_time will be used. Corresponds to the JSON property startTime

Returns:

  • (String)


1412
1413
1414
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1412

def start_time
  @start_time
end

#string_valueString

A text string value. Corresponds to the JSON property stringValue

Returns:

  • (String)


1417
1418
1419
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1417

def string_value
  @string_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1424

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @distribution_value = args[:distribution_value] if args.key?(:distribution_value)
  @double_value = args[:double_value] if args.key?(:double_value)
  @end_time = args[:end_time] if args.key?(:end_time)
  @int64_value = args[:int64_value] if args.key?(:int64_value)
  @labels = args[:labels] if args.key?(:labels)
  @money_value = args[:money_value] if args.key?(:money_value)
  @start_time = args[:start_time] if args.key?(:start_time)
  @string_value = args[:string_value] if args.key?(:string_value)
end