Class: Google::Apis::ServicecontrolV1::Peer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

This message defines attributes for a node that handles a network request. The node can be either a service or an application that sends, forwards, or receives the request. Service peers should fill in principal and labels as appropriate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Peer

Returns a new instance of Peer.



1739
1740
1741
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1739

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ipString

The IP address of the peer. Corresponds to the JSON property ip

Returns:

  • (String)


1713
1714
1715
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1713

def ip
  @ip
end

#labelsHash<String,String>

The labels associated with the peer. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1718
1719
1720
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1718

def labels
  @labels
end

#portFixnum

The network port of the peer. Corresponds to the JSON property port

Returns:

  • (Fixnum)


1723
1724
1725
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1723

def port
  @port
end

#principalString

The identity of this peer. Similar to Request.auth.principal, but relative to the peer instead of the request. For example, the identity associated with a load balancer that forwarded the request. Corresponds to the JSON property principal

Returns:

  • (String)


1730
1731
1732
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1730

def principal
  @principal
end

#region_codeString

The CLDR country/region code associated with the above IP address. If the IP address is private, the region_code should reflect the physical location where this peer is running. Corresponds to the JSON property regionCode

Returns:

  • (String)


1737
1738
1739
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1737

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1744
1745
1746
1747
1748
1749
1750
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1744

def update!(**args)
  @ip = args[:ip] if args.key?(:ip)
  @labels = args[:labels] if args.key?(:labels)
  @port = args[:port] if args.key?(:port)
  @principal = args[:principal] if args.key?(:principal)
  @region_code = args[:region_code] if args.key?(:region_code)
end