Class: Google::Apis::ServicecontrolV1::Request

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

This message defines attributes for an HTTP request. If the actual request is not an HTTP request, the runtime system should try to map the actual request to an equivalent HTTP request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Request

Returns a new instance of Request.



2202
2203
2204
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2202

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authGoogle::Apis::ServicecontrolV1::Auth

This message defines request authentication attributes. Terminology is based on the JSON Web Token (JWT) standard, but the terms also correlate to concepts in other standards. Corresponds to the JSON property auth



2128
2129
2130
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2128

def auth
  @auth
end

#headersHash<String,String>

The HTTP request headers. If multiple headers share the same key, they must be merged according to the HTTP spec. All header keys must be lowercased, because HTTP header keys are case-insensitive. Corresponds to the JSON property headers

Returns:

  • (Hash<String,String>)


2135
2136
2137
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2135

def headers
  @headers
end

#hostString

The HTTP request Host header value. Corresponds to the JSON property host

Returns:

  • (String)


2140
2141
2142
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2140

def host
  @host
end

#idString

The unique ID for a request, which can be propagated to downstream systems. The ID should have low probability of collision within a single day for a specific service. Corresponds to the JSON property id

Returns:

  • (String)


2147
2148
2149
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2147

def id
  @id
end

#method_propString

The HTTP request method, such as GET, POST. Corresponds to the JSON property method

Returns:

  • (String)


2152
2153
2154
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2152

def method_prop
  @method_prop
end

#originString

The values from Origin header from the HTTP request, such as "https://console. cloud.google.com". Modern browsers can only have one origin. Special browsers and/or HTTP clients may require multiple origins. Corresponds to the JSON property origin

Returns:

  • (String)


2159
2160
2161
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2159

def origin
  @origin
end

#pathString

The HTTP URL path, excluding the query parameters. Corresponds to the JSON property path

Returns:

  • (String)


2164
2165
2166
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2164

def path
  @path
end

#protocolString

The network protocol used with the request, such as "http/1.1", "spdy/3", "h2", "h2c", "webrtc", "tcp", "udp", "quic". See https://www.iana.org/assignments/ tls-extensiontype-values/tls-extensiontype-values.xhtml#alpn-protocol-ids for details. Corresponds to the JSON property protocol

Returns:

  • (String)


2172
2173
2174
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2172

def protocol
  @protocol
end

#queryString

The HTTP URL query in the format of name1=value1&name2=value2, as it appears in the first line of the HTTP request. No decoding is performed. Corresponds to the JSON property query

Returns:

  • (String)


2178
2179
2180
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2178

def query
  @query
end

#reasonString

A special parameter for request reason. It is used by security systems to associate auditing information with a request. Corresponds to the JSON property reason

Returns:

  • (String)


2184
2185
2186
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2184

def reason
  @reason
end

#schemeString

The HTTP URL scheme, such as http and https. Corresponds to the JSON property scheme

Returns:

  • (String)


2189
2190
2191
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2189

def scheme
  @scheme
end

#sizeFixnum

The HTTP request size in bytes. If unknown, it must be -1. Corresponds to the JSON property size

Returns:

  • (Fixnum)


2194
2195
2196
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2194

def size
  @size
end

#timeString

The timestamp when the destination service receives the last byte of the request. Corresponds to the JSON property time

Returns:

  • (String)


2200
2201
2202
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2200

def time
  @time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2207

def update!(**args)
  @auth = args[:auth] if args.key?(:auth)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @id = args[:id] if args.key?(:id)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @origin = args[:origin] if args.key?(:origin)
  @path = args[:path] if args.key?(:path)
  @protocol = args[:protocol] if args.key?(:protocol)
  @query = args[:query] if args.key?(:query)
  @reason = args[:reason] if args.key?(:reason)
  @scheme = args[:scheme] if args.key?(:scheme)
  @size = args[:size] if args.key?(:size)
  @time = args[:time] if args.key?(:time)
end