Class: Google::Apis::ServicecontrolV1::ServiceDelegationHistory
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::ServiceDelegationHistory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
The history of delegation across multiple services as the result of the original user's action. Such as "service A uses its own account to do something for user B". This differs from ServiceAccountDelegationInfo, which only tracks the history of direct token exchanges (impersonation).
Instance Attribute Summary collapse
-
#original_principal ⇒ String
The original end user who initiated the request to GCP.
-
#service_metadata ⇒ Array<Google::Apis::ServicecontrolV1::ServiceMetadata>
Data identifying the service specific jobs or units of work that were involved in a chain of service calls.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceDelegationHistory
constructor
A new instance of ServiceDelegationHistory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceDelegationHistory
Returns a new instance of ServiceDelegationHistory.
2533 2534 2535 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#original_principal ⇒ String
The original end user who initiated the request to GCP.
Corresponds to the JSON property originalPrincipal
2525 2526 2527 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2525 def original_principal @original_principal end |
#service_metadata ⇒ Array<Google::Apis::ServicecontrolV1::ServiceMetadata>
Data identifying the service specific jobs or units of work that were involved
in a chain of service calls.
Corresponds to the JSON property serviceMetadata
2531 2532 2533 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2531 def @service_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2538 2539 2540 2541 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2538 def update!(**args) @original_principal = args[:original_principal] if args.key?(:original_principal) @service_metadata = args[:service_metadata] if args.key?(:service_metadata) end |