Class: Google::Apis::ServicecontrolV1::ServiceMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

Metadata describing the service and additional service specific information used to identify the job or unit of work at hand.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceMetadata

Returns a new instance of ServiceMetadata.



2469
2470
2471
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2469

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#job_metadataHash<String,Object>

Additional metadata provided by service teams to describe service specific job information that was triggered by the original principal. Corresponds to the JSON property jobMetadata

Returns:

  • (Hash<String,Object>)


2449
2450
2451
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2449

def 
  @job_metadata
end

#principal_subjectString

A string representing the principal_subject associated with the identity. For most identities, the format will be principal://iam.googleapis.com/identity pool name/subject/subject)except for some GKE identities (GKE_WORKLOAD, FREEFORM, GKE_HUB_WORKLOAD) that are still in the legacy format serviceAccount:identity pool name[subject]If the identity is a Google account (e.g. workspace user account or service account), this will be the email of the prefixed byserviceAccount:. For example:serviceAccount:my- service-account@project-1.iam.gserviceaccount.com. If the identity is an individual user, the identity will be formatted as:user:user_ABC@email.com. Corresponds to the JSON propertyprincipalSubject`

Returns:

  • (String)


2462
2463
2464
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2462

def principal_subject
  @principal_subject
end

#service_domainString

The service's fully qualified domain name, e.g. "dataproc.googleapis.com". Corresponds to the JSON property serviceDomain

Returns:

  • (String)


2467
2468
2469
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2467

def service_domain
  @service_domain
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2474
2475
2476
2477
2478
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2474

def update!(**args)
  @job_metadata = args[:job_metadata] if args.key?(:job_metadata)
  @principal_subject = args[:principal_subject] if args.key?(:principal_subject)
  @service_domain = args[:service_domain] if args.key?(:service_domain)
end