Class: Google::Apis::ServicecontrolV1::TruncatableString
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::TruncatableString
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
Represents a string that might be shortened to a specified length.
Instance Attribute Summary collapse
-
#truncated_byte_count ⇒ Fixnum
The number of bytes removed from the original string.
-
#value ⇒ String
The shortened string.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TruncatableString
constructor
A new instance of TruncatableString.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TruncatableString
Returns a new instance of TruncatableString.
2790 2791 2792 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2790 def initialize(**args) update!(**args) end |
Instance Attribute Details
#truncated_byte_count ⇒ Fixnum
The number of bytes removed from the original string. If this value is 0, then
the string was not shortened.
Corresponds to the JSON property truncatedByteCount
2779 2780 2781 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2779 def truncated_byte_count @truncated_byte_count end |
#value ⇒ String
The shortened string. For example, if the original string is 500 bytes long
and the limit of the string is 128 bytes, then value contains the first 128
bytes of the 500-byte string. Truncation always happens on a UTF8 character
boundary. If there are multi-byte characters in the string, then the length of
the shortened string might be less than the size limit.
Corresponds to the JSON property value
2788 2789 2790 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2788 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2795 2796 2797 2798 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2795 def update!(**args) @truncated_byte_count = args[:truncated_byte_count] if args.key?(:truncated_byte_count) @value = args[:value] if args.key?(:value) end |