Class: Google::Apis::ServicecontrolV1::V1LogEntry
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::V1LogEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
An individual log entry.
Instance Attribute Summary collapse
-
#http_request ⇒ Google::Apis::ServicecontrolV1::V1HttpRequest
A common proto for logging HTTP requests.
-
#insert_id ⇒ String
A unique ID for the log entry used for deduplication.
-
#labels ⇒ Hash<String,String>
A set of user-defined (key, value) data that provides additional information about the log entry.
-
#monitored_resource_labels ⇒ Hash<String,String>
A set of user-defined (key, value) data that provides additional information about the moniotored resource that the log entry belongs to.
-
#name ⇒ String
Required.
-
#operation ⇒ Google::Apis::ServicecontrolV1::V1LogEntryOperation
Additional information about a potentially long-running operation with which a log entry is associated.
-
#proto_payload ⇒ Hash<String,Object>
The log entry payload, represented as a protocol buffer that is expressed as a JSON object.
-
#severity ⇒ String
The severity of the log entry.
-
#source_location ⇒ Google::Apis::ServicecontrolV1::V1LogEntrySourceLocation
Additional information about the source code location that produced the log entry.
-
#struct_payload ⇒ Hash<String,Object>
The log entry payload, represented as a structure that is expressed as a JSON object.
-
#text_payload ⇒ String
The log entry payload, represented as a Unicode string (UTF-8).
-
#timestamp ⇒ String
The time the event described by the log entry occurred.
-
#trace ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ V1LogEntry
constructor
A new instance of V1LogEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ V1LogEntry
Returns a new instance of V1LogEntry.
3003 3004 3005 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3003 def initialize(**args) update!(**args) end |
Instance Attribute Details
#http_request ⇒ Google::Apis::ServicecontrolV1::V1HttpRequest
A common proto for logging HTTP requests. Only contains semantics defined by
the HTTP specification. Product-specific logging information MUST be defined
in a separate message.
Corresponds to the JSON property httpRequest
2929 2930 2931 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2929 def http_request @http_request end |
#insert_id ⇒ String
A unique ID for the log entry used for deduplication. If omitted, the
implementation will generate one based on operation_id.
Corresponds to the JSON property insertId
2935 2936 2937 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2935 def insert_id @insert_id end |
#labels ⇒ Hash<String,String>
A set of user-defined (key, value) data that provides additional information
about the log entry.
Corresponds to the JSON property labels
2941 2942 2943 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2941 def labels @labels end |
#monitored_resource_labels ⇒ Hash<String,String>
A set of user-defined (key, value) data that provides additional information
about the moniotored resource that the log entry belongs to.
Corresponds to the JSON property monitoredResourceLabels
2947 2948 2949 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2947 def monitored_resource_labels @monitored_resource_labels end |
#name ⇒ String
Required. The log to which this log entry belongs. Examples: "syslog", "
book_log".
Corresponds to the JSON property name
2953 2954 2955 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2953 def name @name end |
#operation ⇒ Google::Apis::ServicecontrolV1::V1LogEntryOperation
Additional information about a potentially long-running operation with which a
log entry is associated.
Corresponds to the JSON property operation
2959 2960 2961 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2959 def operation @operation end |
#proto_payload ⇒ Hash<String,Object>
The log entry payload, represented as a protocol buffer that is expressed as a
JSON object. The only accepted type currently is AuditLog.
Corresponds to the JSON property protoPayload
2965 2966 2967 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2965 def proto_payload @proto_payload end |
#severity ⇒ String
The severity of the log entry. The default value is LogSeverity.DEFAULT.
Corresponds to the JSON property severity
2970 2971 2972 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2970 def severity @severity end |
#source_location ⇒ Google::Apis::ServicecontrolV1::V1LogEntrySourceLocation
Additional information about the source code location that produced the log
entry.
Corresponds to the JSON property sourceLocation
2976 2977 2978 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2976 def source_location @source_location end |
#struct_payload ⇒ Hash<String,Object>
The log entry payload, represented as a structure that is expressed as a JSON
object.
Corresponds to the JSON property structPayload
2982 2983 2984 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2982 def struct_payload @struct_payload end |
#text_payload ⇒ String
The log entry payload, represented as a Unicode string (UTF-8).
Corresponds to the JSON property textPayload
2987 2988 2989 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2987 def text_payload @text_payload end |
#timestamp ⇒ String
The time the event described by the log entry occurred. If omitted, defaults
to operation start time.
Corresponds to the JSON property timestamp
2993 2994 2995 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2993 def @timestamp end |
#trace ⇒ String
Optional. Resource name of the trace associated with the log entry, if any. If
this field contains a relative resource name, you can assume the name is
relative to //tracing.googleapis.com. Example: projects/my-projectid/traces/
06796866738c859f2f19b7cfb3214824
Corresponds to the JSON property trace
3001 3002 3003 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3001 def trace @trace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3008 def update!(**args) @http_request = args[:http_request] if args.key?(:http_request) @insert_id = args[:insert_id] if args.key?(:insert_id) @labels = args[:labels] if args.key?(:labels) @monitored_resource_labels = args[:monitored_resource_labels] if args.key?(:monitored_resource_labels) @name = args[:name] if args.key?(:name) @operation = args[:operation] if args.key?(:operation) @proto_payload = args[:proto_payload] if args.key?(:proto_payload) @severity = args[:severity] if args.key?(:severity) @source_location = args[:source_location] if args.key?(:source_location) @struct_payload = args[:struct_payload] if args.key?(:struct_payload) @text_payload = args[:text_payload] if args.key?(:text_payload) @timestamp = args[:timestamp] if args.key?(:timestamp) @trace = args[:trace] if args.key?(:trace) end |