Class: Google::Apis::ServicecontrolV1::AuditLog
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::AuditLog
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
Common audit log format for Google Cloud Platform API operations.
Instance Attribute Summary collapse
-
#api_version_identifier ⇒ String
The API version identifier of the operation that uses interface based versioning (IBV).
-
#authentication_info ⇒ Google::Apis::ServicecontrolV1::AuthenticationInfo
Authentication information for the operation.
-
#authorization_info ⇒ Array<Google::Apis::ServicecontrolV1::AuthorizationInfo>
Authorization information.
-
#metadata ⇒ Hash<String,Object>
Other service-specific data about the request, response, and other information associated with the current audited event.
-
#method_name ⇒ String
The name of the service method or operation.
-
#num_response_items ⇒ Fixnum
The number of items returned from a List or Query API method, if applicable.
-
#policy_violation_info ⇒ Google::Apis::ServicecontrolV1::PolicyViolationInfo
Information related to policy violations for this request.
-
#request ⇒ Hash<String,Object>
The operation request.
-
#request_metadata ⇒ Google::Apis::ServicecontrolV1::RequestMetadata
Metadata about the request.
-
#resource_location ⇒ Google::Apis::ServicecontrolV1::ResourceLocation
Location information about a resource.
-
#resource_name ⇒ String
The resource or collection that is the target of the operation.
-
#resource_original_state ⇒ Hash<String,Object>
The resource's original state before mutation.
-
#response ⇒ Hash<String,Object>
The operation response.
-
#service_data ⇒ Hash<String,Object>
Deprecated.
-
#service_name ⇒ String
The name of the API service performing the operation.
-
#status ⇒ Google::Apis::ServicecontrolV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuditLog
constructor
A new instance of AuditLog.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuditLog
Returns a new instance of AuditLog.
301 302 303 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 301 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version_identifier ⇒ String
The API version identifier of the operation that uses interface based
versioning (IBV). For example, "2026-01-01-preview". The version identifier
generally follows the format of [variant_]date[_decorator]. It should not be
parsed because the exact format varies across services.
Corresponds to the JSON property apiVersionIdentifier
196 197 198 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 196 def api_version_identifier @api_version_identifier end |
#authentication_info ⇒ Google::Apis::ServicecontrolV1::AuthenticationInfo
Authentication information for the operation.
Corresponds to the JSON property authenticationInfo
201 202 203 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 201 def authentication_info @authentication_info end |
#authorization_info ⇒ Array<Google::Apis::ServicecontrolV1::AuthorizationInfo>
Authorization information. If there are multiple resources or permissions
involved, then there is one AuthorizationInfo element for each resource,
permission tuple.
Corresponds to the JSON property authorizationInfo
208 209 210 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 208 def @authorization_info end |
#metadata ⇒ Hash<String,Object>
Other service-specific data about the request, response, and other information
associated with the current audited event.
Corresponds to the JSON property metadata
214 215 216 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 214 def @metadata end |
#method_name ⇒ String
The name of the service method or operation. For API calls, this should be the
name of the API method. For example, "google.cloud.bigquery.v2.TableService.
InsertTable" "google.logging.v2.ConfigServiceV2.CreateSink"
Corresponds to the JSON property methodName
221 222 223 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 221 def method_name @method_name end |
#num_response_items ⇒ Fixnum
The number of items returned from a List or Query API method, if applicable.
Corresponds to the JSON property numResponseItems
226 227 228 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 226 def num_response_items @num_response_items end |
#policy_violation_info ⇒ Google::Apis::ServicecontrolV1::PolicyViolationInfo
Information related to policy violations for this request.
Corresponds to the JSON property policyViolationInfo
231 232 233 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 231 def policy_violation_info @policy_violation_info end |
#request ⇒ Hash<String,Object>
The operation request. This may not include all request parameters, such as
those that are too large, privacy-sensitive, or duplicated elsewhere in the
log record. It should never include user-generated data, such as file contents.
When the JSON object represented here has a proto equivalent, the proto name
will be indicated in the @type property.
Corresponds to the JSON property request
240 241 242 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 240 def request @request end |
#request_metadata ⇒ Google::Apis::ServicecontrolV1::RequestMetadata
Metadata about the request.
Corresponds to the JSON property requestMetadata
245 246 247 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 245 def @request_metadata end |
#resource_location ⇒ Google::Apis::ServicecontrolV1::ResourceLocation
Location information about a resource.
Corresponds to the JSON property resourceLocation
250 251 252 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 250 def resource_location @resource_location end |
#resource_name ⇒ String
The resource or collection that is the target of the operation. The name is a
scheme-less URI, not including the API service name. For example: "projects/
PROJECT_ID/zones/us-central1-a/instances" "projects/PROJECT_ID/datasets/
DATASET_ID"
Corresponds to the JSON property resourceName
258 259 260 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 258 def resource_name @resource_name end |
#resource_original_state ⇒ Hash<String,Object>
The resource's original state before mutation. Present only for operations
which have successfully modified the targeted resource(s). In general, this
field should contain all changed fields, except those that are already been
included in request, response, metadata or service_data fields. When
the JSON object represented here has a proto equivalent, the proto name will
be indicated in the @type property.
Corresponds to the JSON property resourceOriginalState
268 269 270 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 268 def resource_original_state @resource_original_state end |
#response ⇒ Hash<String,Object>
The operation response. This may not include all response elements, such as
those that are too large, privacy-sensitive, or duplicated elsewhere in the
log record. It should never include user-generated data, such as file contents.
When the JSON object represented here has a proto equivalent, the proto name
will be indicated in the @type property.
Corresponds to the JSON property response
277 278 279 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 277 def response @response end |
#service_data ⇒ Hash<String,Object>
Deprecated. Use the metadata field instead. Other service-specific data
about the request, response, and other activities.
Corresponds to the JSON property serviceData
283 284 285 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 283 def service_data @service_data end |
#service_name ⇒ String
The name of the API service performing the operation. For example, "compute.
googleapis.com".
Corresponds to the JSON property serviceName
289 290 291 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 289 def service_name @service_name end |
#status ⇒ Google::Apis::ServicecontrolV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
299 300 301 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 299 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 306 def update!(**args) @api_version_identifier = args[:api_version_identifier] if args.key?(:api_version_identifier) @authentication_info = args[:authentication_info] if args.key?(:authentication_info) @authorization_info = args[:authorization_info] if args.key?(:authorization_info) @metadata = args[:metadata] if args.key?(:metadata) @method_name = args[:method_name] if args.key?(:method_name) @num_response_items = args[:num_response_items] if args.key?(:num_response_items) @policy_violation_info = args[:policy_violation_info] if args.key?(:policy_violation_info) @request = args[:request] if args.key?(:request) @request_metadata = args[:request_metadata] if args.key?(:request_metadata) @resource_location = args[:resource_location] if args.key?(:resource_location) @resource_name = args[:resource_name] if args.key?(:resource_name) @resource_original_state = args[:resource_original_state] if args.key?(:resource_original_state) @response = args[:response] if args.key?(:response) @service_data = args[:service_data] if args.key?(:service_data) @service_name = args[:service_name] if args.key?(:service_name) @status = args[:status] if args.key?(:status) end |