Class: Google::Apis::ServicecontrolV1::CheckError
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::CheckError
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
Defines the errors to be returned in google.api.servicecontrol.v1. CheckResponse.check_errors.
Instance Attribute Summary collapse
-
#code ⇒ String
The error code.
-
#detail ⇒ String
Free-form text providing details on the error cause of the error.
-
#status ⇒ Google::Apis::ServicecontrolV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#subject ⇒ String
Subject to whom this error applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CheckError
constructor
A new instance of CheckError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CheckError
Returns a new instance of CheckError.
620 621 622 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 620 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The error code.
Corresponds to the JSON property code
597 598 599 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 597 def code @code end |
#detail ⇒ String
Free-form text providing details on the error cause of the error.
Corresponds to the JSON property detail
602 603 604 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 602 def detail @detail end |
#status ⇒ Google::Apis::ServicecontrolV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
612 613 614 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 612 def status @status end |
#subject ⇒ String
Subject to whom this error applies. See the specific code enum for more
details on this field. For example: - "project:" - "folder:" - "organization:"
Corresponds to the JSON property subject
618 619 620 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 618 def subject @subject end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
625 626 627 628 629 630 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 625 def update!(**args) @code = args[:code] if args.key?(:code) @detail = args[:detail] if args.key?(:detail) @status = args[:status] if args.key?(:status) @subject = args[:subject] if args.key?(:subject) end |