Class: Google::Apis::ServicecontrolV1::CheckError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

Defines the errors to be returned in google.api.servicecontrol.v1. CheckResponse.check_errors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CheckError

Returns a new instance of CheckError.



574
575
576
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 574

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

The error code. Corresponds to the JSON property code

Returns:

  • (String)


551
552
553
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 551

def code
  @code
end

#detailString

Free-form text providing details on the error cause of the error. Corresponds to the JSON property detail

Returns:

  • (String)


556
557
558
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 556

def detail
  @detail
end

#statusGoogle::Apis::ServicecontrolV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



566
567
568
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 566

def status
  @status
end

#subjectString

Subject to whom this error applies. See the specific code enum for more details on this field. For example: - "project:" - "folder:" - "organization:" Corresponds to the JSON property subject

Returns:

  • (String)


572
573
574
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 572

def subject
  @subject
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



579
580
581
582
583
584
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 579

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @detail = args[:detail] if args.key?(:detail)
  @status = args[:status] if args.key?(:status)
  @subject = args[:subject] if args.key?(:subject)
end