Class: Google::Apis::ServicecontrolV1::CheckError
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::CheckError
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
Defines the errors to be returned in google.api.servicecontrol.v1. CheckResponse.check_errors.
Instance Attribute Summary collapse
-
#code ⇒ String
The error code.
-
#detail ⇒ String
Free-form text providing details on the error cause of the error.
-
#status ⇒ Google::Apis::ServicecontrolV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#subject ⇒ String
Subject to whom this error applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CheckError
constructor
A new instance of CheckError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CheckError
Returns a new instance of CheckError.
565 566 567 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The error code.
Corresponds to the JSON property code
542 543 544 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 542 def code @code end |
#detail ⇒ String
Free-form text providing details on the error cause of the error.
Corresponds to the JSON property detail
547 548 549 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 547 def detail @detail end |
#status ⇒ Google::Apis::ServicecontrolV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
557 558 559 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 557 def status @status end |
#subject ⇒ String
Subject to whom this error applies. See the specific code enum for more
details on this field. For example: - "project:" - "folder:" - "organization:"
Corresponds to the JSON property subject
563 564 565 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 563 def subject @subject end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
570 571 572 573 574 575 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 570 def update!(**args) @code = args[:code] if args.key?(:code) @detail = args[:detail] if args.key?(:detail) @status = args[:status] if args.key?(:status) @subject = args[:subject] if args.key?(:subject) end |