Class: Google::Apis::ServicecontrolV1::CheckRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::CheckRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
Request message for the Check method.
Instance Attribute Summary collapse
-
#operation ⇒ Google::Apis::ServicecontrolV1::Operation
Represents information regarding an operation.
-
#request_project_settings ⇒ Boolean
(also: #request_project_settings?)
Requests the project settings to be returned as part of the check response.
-
#service_config_id ⇒ String
Specifies which version of service configuration should be used to process the request.
-
#skip_activation_check ⇒ Boolean
(also: #skip_activation_check?)
Indicates if service activation check should be skipped for this request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CheckRequest
constructor
A new instance of CheckRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CheckRequest
Returns a new instance of CheckRequest.
651 652 653 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 651 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operation ⇒ Google::Apis::ServicecontrolV1::Operation
Represents information regarding an operation.
Corresponds to the JSON property operation
628 629 630 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 628 def operation @operation end |
#request_project_settings ⇒ Boolean Also known as: request_project_settings?
Requests the project settings to be returned as part of the check response.
Corresponds to the JSON property requestProjectSettings
633 634 635 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 633 def request_project_settings @request_project_settings end |
#service_config_id ⇒ String
Specifies which version of service configuration should be used to process the
request. If unspecified or no matching version can be found, the latest one
will be used.
Corresponds to the JSON property serviceConfigId
641 642 643 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 641 def service_config_id @service_config_id end |
#skip_activation_check ⇒ Boolean Also known as: skip_activation_check?
Indicates if service activation check should be skipped for this request.
Default behavior is to perform the check and apply relevant quota. WARNING:
Setting this flag to "true" will disable quota enforcement.
Corresponds to the JSON property skipActivationCheck
648 649 650 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 648 def skip_activation_check @skip_activation_check end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
656 657 658 659 660 661 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 656 def update!(**args) @operation = args[:operation] if args.key?(:operation) @request_project_settings = args[:request_project_settings] if args.key?(:request_project_settings) @service_config_id = args[:service_config_id] if args.key?(:service_config_id) @skip_activation_check = args[:skip_activation_check] if args.key?(:skip_activation_check) end |