Class: Google::Apis::ServicecontrolV1::CheckResponse
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::CheckResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
Response message for the Check method.
Instance Attribute Summary collapse
-
#check_errors ⇒ Array<Google::Apis::ServicecontrolV1::CheckError>
Indicate the decision of the check.
-
#check_info ⇒ Google::Apis::ServicecontrolV1::CheckInfo
Contains additional information about the check operation.
-
#operation_id ⇒ String
The same operation_id value used in the CheckRequest.
-
#quota_info ⇒ Google::Apis::ServicecontrolV1::QuotaInfo
Contains the quota information for a quota check response.
-
#service_config_id ⇒ String
The actual config id used to process the request.
-
#service_rollout_id ⇒ String
The current service rollout id used to process the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CheckResponse
constructor
A new instance of CheckResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CheckResponse
Returns a new instance of CheckResponse.
756 757 758 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 756 def initialize(**args) update!(**args) end |
Instance Attribute Details
#check_errors ⇒ Array<Google::Apis::ServicecontrolV1::CheckError>
Indicate the decision of the check. If no check errors are present, the
service should process the operation. Otherwise the service should use the
list of errors to determine the appropriate action.
Corresponds to the JSON property checkErrors
728 729 730 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 728 def check_errors @check_errors end |
#check_info ⇒ Google::Apis::ServicecontrolV1::CheckInfo
Contains additional information about the check operation.
Corresponds to the JSON property checkInfo
733 734 735 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 733 def check_info @check_info end |
#operation_id ⇒ String
The same operation_id value used in the CheckRequest. Used for logging and
diagnostics purposes.
Corresponds to the JSON property operationId
739 740 741 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 739 def operation_id @operation_id end |
#quota_info ⇒ Google::Apis::ServicecontrolV1::QuotaInfo
Contains the quota information for a quota check response.
Corresponds to the JSON property quotaInfo
744 745 746 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 744 def quota_info @quota_info end |
#service_config_id ⇒ String
The actual config id used to process the request.
Corresponds to the JSON property serviceConfigId
749 750 751 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 749 def service_config_id @service_config_id end |
#service_rollout_id ⇒ String
The current service rollout id used to process the request.
Corresponds to the JSON property serviceRolloutId
754 755 756 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 754 def service_rollout_id @service_rollout_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
761 762 763 764 765 766 767 768 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 761 def update!(**args) @check_errors = args[:check_errors] if args.key?(:check_errors) @check_info = args[:check_info] if args.key?(:check_info) @operation_id = args[:operation_id] if args.key?(:operation_id) @quota_info = args[:quota_info] if args.key?(:quota_info) @service_config_id = args[:service_config_id] if args.key?(:service_config_id) @service_rollout_id = args[:service_rollout_id] if args.key?(:service_rollout_id) end |