Class: Google::Apis::ServicecontrolV1::CheckResponse
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::CheckResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
Response message for the Check method.
Instance Attribute Summary collapse
-
#check_errors ⇒ Array<Google::Apis::ServicecontrolV1::CheckError>
Indicate the decision of the check.
-
#check_info ⇒ Google::Apis::ServicecontrolV1::CheckInfo
Contains additional information about the check operation.
-
#operation_id ⇒ String
The same operation_id value used in the CheckRequest.
-
#quota_info ⇒ Google::Apis::ServicecontrolV1::QuotaInfo
Contains the quota information for a quota check response.
-
#service_config_id ⇒ String
The actual config id used to process the request.
-
#service_rollout_id ⇒ String
The current service rollout id used to process the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CheckResponse
constructor
A new instance of CheckResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CheckResponse
Returns a new instance of CheckResponse.
701 702 703 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 701 def initialize(**args) update!(**args) end |
Instance Attribute Details
#check_errors ⇒ Array<Google::Apis::ServicecontrolV1::CheckError>
Indicate the decision of the check. If no check errors are present, the
service should process the operation. Otherwise the service should use the
list of errors to determine the appropriate action.
Corresponds to the JSON property checkErrors
673 674 675 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 673 def check_errors @check_errors end |
#check_info ⇒ Google::Apis::ServicecontrolV1::CheckInfo
Contains additional information about the check operation.
Corresponds to the JSON property checkInfo
678 679 680 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 678 def check_info @check_info end |
#operation_id ⇒ String
The same operation_id value used in the CheckRequest. Used for logging and
diagnostics purposes.
Corresponds to the JSON property operationId
684 685 686 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 684 def operation_id @operation_id end |
#quota_info ⇒ Google::Apis::ServicecontrolV1::QuotaInfo
Contains the quota information for a quota check response.
Corresponds to the JSON property quotaInfo
689 690 691 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 689 def quota_info @quota_info end |
#service_config_id ⇒ String
The actual config id used to process the request.
Corresponds to the JSON property serviceConfigId
694 695 696 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 694 def service_config_id @service_config_id end |
#service_rollout_id ⇒ String
The current service rollout id used to process the request.
Corresponds to the JSON property serviceRolloutId
699 700 701 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 699 def service_rollout_id @service_rollout_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
706 707 708 709 710 711 712 713 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 706 def update!(**args) @check_errors = args[:check_errors] if args.key?(:check_errors) @check_info = args[:check_info] if args.key?(:check_info) @operation_id = args[:operation_id] if args.key?(:operation_id) @quota_info = args[:quota_info] if args.key?(:quota_info) @service_config_id = args[:service_config_id] if args.key?(:service_config_id) @service_rollout_id = args[:service_rollout_id] if args.key?(:service_rollout_id) end |