Class: Google::Apis::ServicecontrolV1::HttpRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::HttpRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
A common proto for logging HTTP requests. Only contains semantics defined by the HTTP specification. Product-specific logging information MUST be defined in a separate message.
Instance Attribute Summary collapse
-
#cache_fill_bytes ⇒ Fixnum
The number of HTTP response bytes inserted into cache.
-
#cache_hit ⇒ Boolean
(also: #cache_hit?)
Whether or not an entity was served from cache (with or without validation).
-
#cache_lookup ⇒ Boolean
(also: #cache_lookup?)
Whether or not a cache lookup was attempted.
-
#cache_validated_with_origin_server ⇒ Boolean
(also: #cache_validated_with_origin_server?)
Whether or not the response was validated with the origin server before being served from cache.
-
#latency ⇒ String
The request processing latency on the server, from the time the request was received until the response was sent.
-
#protocol ⇒ String
Protocol used for the request.
-
#referer ⇒ String
The referer URL of the request, as defined in HTTP/1.1 Header Field Definitions.
-
#remote_ip ⇒ String
The IP address (IPv4 or IPv6) of the client that issued the HTTP request.
-
#request_method ⇒ String
The request method.
-
#request_size ⇒ Fixnum
The size of the HTTP request message in bytes, including the request headers and the request body.
-
#request_url ⇒ String
The scheme (http, https), the host name, the path, and the query portion of the URL that was requested.
-
#response_size ⇒ Fixnum
The size of the HTTP response message sent back to the client, in bytes, including the response headers and the response body.
-
#server_ip ⇒ String
The IP address (IPv4 or IPv6) of the origin server that the request was sent to.
-
#status ⇒ Fixnum
The response code indicating the status of the response.
-
#user_agent ⇒ String
The user agent sent by the client.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRequest
constructor
A new instance of HttpRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRequest
Returns a new instance of HttpRequest.
1073 1074 1075 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1073 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cache_fill_bytes ⇒ Fixnum
The number of HTTP response bytes inserted into cache. Set only when a cache
fill was attempted.
Corresponds to the JSON property cacheFillBytes
988 989 990 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 988 def cache_fill_bytes @cache_fill_bytes end |
#cache_hit ⇒ Boolean Also known as: cache_hit?
Whether or not an entity was served from cache (with or without validation).
Corresponds to the JSON property cacheHit
993 994 995 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 993 def cache_hit @cache_hit end |
#cache_lookup ⇒ Boolean Also known as: cache_lookup?
Whether or not a cache lookup was attempted.
Corresponds to the JSON property cacheLookup
999 1000 1001 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 999 def cache_lookup @cache_lookup end |
#cache_validated_with_origin_server ⇒ Boolean Also known as: cache_validated_with_origin_server?
Whether or not the response was validated with the origin server before being
served from cache. This field is only meaningful if cache_hit is True.
Corresponds to the JSON property cacheValidatedWithOriginServer
1006 1007 1008 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1006 def cache_validated_with_origin_server @cache_validated_with_origin_server end |
#latency ⇒ String
The request processing latency on the server, from the time the request was
received until the response was sent.
Corresponds to the JSON property latency
1013 1014 1015 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1013 def latency @latency end |
#protocol ⇒ String
Protocol used for the request. Examples: "HTTP/1.1", "HTTP/2", "websocket"
Corresponds to the JSON property protocol
1018 1019 1020 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1018 def protocol @protocol end |
#referer ⇒ String
The referer URL of the request, as defined in HTTP/1.1 Header Field
Definitions.
Corresponds to the JSON property referer
1024 1025 1026 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1024 def referer @referer end |
#remote_ip ⇒ String
The IP address (IPv4 or IPv6) of the client that issued the HTTP request.
Examples: "192.168.1.1", "FE80::0202:B3FF:FE1E:8329".
Corresponds to the JSON property remoteIp
1030 1031 1032 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1030 def remote_ip @remote_ip end |
#request_method ⇒ String
The request method. Examples: "GET", "HEAD", "PUT", "POST".
Corresponds to the JSON property requestMethod
1035 1036 1037 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1035 def request_method @request_method end |
#request_size ⇒ Fixnum
The size of the HTTP request message in bytes, including the request headers
and the request body.
Corresponds to the JSON property requestSize
1041 1042 1043 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1041 def request_size @request_size end |
#request_url ⇒ String
The scheme (http, https), the host name, the path, and the query portion of
the URL that was requested. Example: "http://example.com/some/info?color=red"
.
Corresponds to the JSON property requestUrl
1048 1049 1050 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1048 def request_url @request_url end |
#response_size ⇒ Fixnum
The size of the HTTP response message sent back to the client, in bytes,
including the response headers and the response body.
Corresponds to the JSON property responseSize
1054 1055 1056 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1054 def response_size @response_size end |
#server_ip ⇒ String
The IP address (IPv4 or IPv6) of the origin server that the request was sent
to.
Corresponds to the JSON property serverIp
1060 1061 1062 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1060 def server_ip @server_ip end |
#status ⇒ Fixnum
The response code indicating the status of the response. Examples: 200, 404.
Corresponds to the JSON property status
1065 1066 1067 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1065 def status @status end |
#user_agent ⇒ String
The user agent sent by the client. Example: "Mozilla/4.0 (compatible; MSIE 6.
0; Windows 98; Q312461; .NET CLR 1.0.3705)".
Corresponds to the JSON property userAgent
1071 1072 1073 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1071 def user_agent @user_agent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1078 def update!(**args) @cache_fill_bytes = args[:cache_fill_bytes] if args.key?(:cache_fill_bytes) @cache_hit = args[:cache_hit] if args.key?(:cache_hit) @cache_lookup = args[:cache_lookup] if args.key?(:cache_lookup) @cache_validated_with_origin_server = args[:cache_validated_with_origin_server] if args.key?(:cache_validated_with_origin_server) @latency = args[:latency] if args.key?(:latency) @protocol = args[:protocol] if args.key?(:protocol) @referer = args[:referer] if args.key?(:referer) @remote_ip = args[:remote_ip] if args.key?(:remote_ip) @request_method = args[:request_method] if args.key?(:request_method) @request_size = args[:request_size] if args.key?(:request_size) @request_url = args[:request_url] if args.key?(:request_url) @response_size = args[:response_size] if args.key?(:response_size) @server_ip = args[:server_ip] if args.key?(:server_ip) @status = args[:status] if args.key?(:status) @user_agent = args[:user_agent] if args.key?(:user_agent) end |