Class: Google::Apis::ServicecontrolV1::MetricValue
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::MetricValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
Represents a single metric value.
Instance Attribute Summary collapse
-
#bool_value ⇒ Boolean
(also: #bool_value?)
A boolean value.
-
#distribution_value ⇒ Google::Apis::ServicecontrolV1::Distribution
Distribution represents a frequency distribution of double-valued sample points.
-
#double_value ⇒ Float
A double precision floating point value.
-
#end_time ⇒ String
The end of the time period over which this metric value's measurement applies.
-
#int64_value ⇒ Fixnum
A signed 64-bit integer value.
-
#labels ⇒ Hash<String,String>
The labels describing the metric value.
-
#money_value ⇒ Google::Apis::ServicecontrolV1::Money
Represents an amount of money with its currency type.
-
#start_time ⇒ String
The start of the time period over which this metric value's measurement applies.
-
#string_value ⇒ String
A text string value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetricValue
constructor
A new instance of MetricValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetricValue
Returns a new instance of MetricValue.
1381 1382 1383 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1381 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_value ⇒ Boolean Also known as: bool_value?
A boolean value.
Corresponds to the JSON property boolValue
1327 1328 1329 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1327 def bool_value @bool_value end |
#distribution_value ⇒ Google::Apis::ServicecontrolV1::Distribution
Distribution represents a frequency distribution of double-valued sample
points. It contains the size of the population of sample points plus
additional optional information: * the arithmetic mean of the samples * the
minimum and maximum of the samples * the sum-squared-deviation of the samples,
used to compute variance * a histogram of the values of the sample points
Corresponds to the JSON property distributionValue
1337 1338 1339 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1337 def distribution_value @distribution_value end |
#double_value ⇒ Float
A double precision floating point value.
Corresponds to the JSON property doubleValue
1342 1343 1344 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1342 def double_value @double_value end |
#end_time ⇒ String
The end of the time period over which this metric value's measurement applies.
If not specified, google.api.servicecontrol.v1.Operation.end_time will be used.
Corresponds to the JSON property endTime
1348 1349 1350 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1348 def end_time @end_time end |
#int64_value ⇒ Fixnum
A signed 64-bit integer value.
Corresponds to the JSON property int64Value
1353 1354 1355 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1353 def int64_value @int64_value end |
#labels ⇒ Hash<String,String>
The labels describing the metric value. See comments on google.api.
servicecontrol.v1.Operation.labels for the overriding relationship. Note that
this map must not contain monitored resource labels.
Corresponds to the JSON property labels
1360 1361 1362 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1360 def labels @labels end |
#money_value ⇒ Google::Apis::ServicecontrolV1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property moneyValue
1365 1366 1367 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1365 def money_value @money_value end |
#start_time ⇒ String
The start of the time period over which this metric value's measurement
applies. The time period has different semantics for different metric types (
cumulative, delta, and gauge). See the metric definition documentation in the
service configuration for details. If not specified, google.api.servicecontrol.
v1.Operation.start_time will be used.
Corresponds to the JSON property startTime
1374 1375 1376 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1374 def start_time @start_time end |
#string_value ⇒ String
A text string value.
Corresponds to the JSON property stringValue
1379 1380 1381 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1379 def string_value @string_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1386 def update!(**args) @bool_value = args[:bool_value] if args.key?(:bool_value) @distribution_value = args[:distribution_value] if args.key?(:distribution_value) @double_value = args[:double_value] if args.key?(:double_value) @end_time = args[:end_time] if args.key?(:end_time) @int64_value = args[:int64_value] if args.key?(:int64_value) @labels = args[:labels] if args.key?(:labels) @money_value = args[:money_value] if args.key?(:money_value) @start_time = args[:start_time] if args.key?(:start_time) @string_value = args[:string_value] if args.key?(:string_value) end |