Class: Google::Apis::ServicecontrolV1::MetricValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

Represents a single metric value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetricValue

Returns a new instance of MetricValue.



1373
1374
1375
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

A boolean value. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


1319
1320
1321
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1319

def bool_value
  @bool_value
end

#distribution_valueGoogle::Apis::ServicecontrolV1::Distribution

Distribution represents a frequency distribution of double-valued sample points. It contains the size of the population of sample points plus additional optional information: * the arithmetic mean of the samples * the minimum and maximum of the samples * the sum-squared-deviation of the samples, used to compute variance * a histogram of the values of the sample points Corresponds to the JSON property distributionValue



1329
1330
1331
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1329

def distribution_value
  @distribution_value
end

#double_valueFloat

A double precision floating point value. Corresponds to the JSON property doubleValue

Returns:

  • (Float)


1334
1335
1336
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1334

def double_value
  @double_value
end

#end_timeString

The end of the time period over which this metric value's measurement applies. If not specified, google.api.servicecontrol.v1.Operation.end_time will be used. Corresponds to the JSON property endTime

Returns:

  • (String)


1340
1341
1342
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1340

def end_time
  @end_time
end

#int64_valueFixnum

A signed 64-bit integer value. Corresponds to the JSON property int64Value

Returns:

  • (Fixnum)


1345
1346
1347
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1345

def int64_value
  @int64_value
end

#labelsHash<String,String>

The labels describing the metric value. See comments on google.api. servicecontrol.v1.Operation.labels for the overriding relationship. Note that this map must not contain monitored resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1352
1353
1354
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1352

def labels
  @labels
end

#money_valueGoogle::Apis::ServicecontrolV1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property moneyValue



1357
1358
1359
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1357

def money_value
  @money_value
end

#start_timeString

The start of the time period over which this metric value's measurement applies. The time period has different semantics for different metric types ( cumulative, delta, and gauge). See the metric definition documentation in the service configuration for details. If not specified, google.api.servicecontrol. v1.Operation.start_time will be used. Corresponds to the JSON property startTime

Returns:

  • (String)


1366
1367
1368
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1366

def start_time
  @start_time
end

#string_valueString

A text string value. Corresponds to the JSON property stringValue

Returns:

  • (String)


1371
1372
1373
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1371

def string_value
  @string_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1378

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @distribution_value = args[:distribution_value] if args.key?(:distribution_value)
  @double_value = args[:double_value] if args.key?(:double_value)
  @end_time = args[:end_time] if args.key?(:end_time)
  @int64_value = args[:int64_value] if args.key?(:int64_value)
  @labels = args[:labels] if args.key?(:labels)
  @money_value = args[:money_value] if args.key?(:money_value)
  @start_time = args[:start_time] if args.key?(:start_time)
  @string_value = args[:string_value] if args.key?(:string_value)
end