Class: Google::Apis::ServicecontrolV1::MetricValue
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::MetricValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
Represents a single metric value.
Instance Attribute Summary collapse
-
#bool_value ⇒ Boolean
(also: #bool_value?)
A boolean value.
-
#distribution_value ⇒ Google::Apis::ServicecontrolV1::Distribution
Distribution represents a frequency distribution of double-valued sample points.
-
#double_value ⇒ Float
A double precision floating point value.
-
#end_time ⇒ String
The end of the time period over which this metric value's measurement applies.
-
#int64_value ⇒ Fixnum
A signed 64-bit integer value.
-
#labels ⇒ Hash<String,String>
The labels describing the metric value.
-
#money_value ⇒ Google::Apis::ServicecontrolV1::Money
Represents an amount of money with its currency type.
-
#start_time ⇒ String
The start of the time period over which this metric value's measurement applies.
-
#string_value ⇒ String
A text string value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetricValue
constructor
A new instance of MetricValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetricValue
Returns a new instance of MetricValue.
1364 1365 1366 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1364 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_value ⇒ Boolean Also known as: bool_value?
A boolean value.
Corresponds to the JSON property boolValue
1310 1311 1312 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1310 def bool_value @bool_value end |
#distribution_value ⇒ Google::Apis::ServicecontrolV1::Distribution
Distribution represents a frequency distribution of double-valued sample
points. It contains the size of the population of sample points plus
additional optional information: * the arithmetic mean of the samples * the
minimum and maximum of the samples * the sum-squared-deviation of the samples,
used to compute variance * a histogram of the values of the sample points
Corresponds to the JSON property distributionValue
1320 1321 1322 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1320 def distribution_value @distribution_value end |
#double_value ⇒ Float
A double precision floating point value.
Corresponds to the JSON property doubleValue
1325 1326 1327 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1325 def double_value @double_value end |
#end_time ⇒ String
The end of the time period over which this metric value's measurement applies.
If not specified, google.api.servicecontrol.v1.Operation.end_time will be used.
Corresponds to the JSON property endTime
1331 1332 1333 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1331 def end_time @end_time end |
#int64_value ⇒ Fixnum
A signed 64-bit integer value.
Corresponds to the JSON property int64Value
1336 1337 1338 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1336 def int64_value @int64_value end |
#labels ⇒ Hash<String,String>
The labels describing the metric value. See comments on google.api.
servicecontrol.v1.Operation.labels for the overriding relationship. Note that
this map must not contain monitored resource labels.
Corresponds to the JSON property labels
1343 1344 1345 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1343 def labels @labels end |
#money_value ⇒ Google::Apis::ServicecontrolV1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property moneyValue
1348 1349 1350 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1348 def money_value @money_value end |
#start_time ⇒ String
The start of the time period over which this metric value's measurement
applies. The time period has different semantics for different metric types (
cumulative, delta, and gauge). See the metric definition documentation in the
service configuration for details. If not specified, google.api.servicecontrol.
v1.Operation.start_time will be used.
Corresponds to the JSON property startTime
1357 1358 1359 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1357 def start_time @start_time end |
#string_value ⇒ String
A text string value.
Corresponds to the JSON property stringValue
1362 1363 1364 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1362 def string_value @string_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1369 def update!(**args) @bool_value = args[:bool_value] if args.key?(:bool_value) @distribution_value = args[:distribution_value] if args.key?(:distribution_value) @double_value = args[:double_value] if args.key?(:double_value) @end_time = args[:end_time] if args.key?(:end_time) @int64_value = args[:int64_value] if args.key?(:int64_value) @labels = args[:labels] if args.key?(:labels) @money_value = args[:money_value] if args.key?(:money_value) @start_time = args[:start_time] if args.key?(:start_time) @string_value = args[:string_value] if args.key?(:string_value) end |