Class: Google::Apis::ServicecontrolV1::MetricValueSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

Represents a set of metric values in the same metric. Each metric value in the set should have a unique combination of start time, end time, and label values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetricValueSet

Returns a new instance of MetricValueSet.



1397
1398
1399
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metric_nameString

The metric name defined in the service configuration. Corresponds to the JSON property metricName

Returns:

  • (String)


1390
1391
1392
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1390

def metric_name
  @metric_name
end

#metric_valuesArray<Google::Apis::ServicecontrolV1::MetricValue>

The values in this metric. Corresponds to the JSON property metricValues



1395
1396
1397
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1395

def metric_values
  @metric_values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1402
1403
1404
1405
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1402

def update!(**args)
  @metric_name = args[:metric_name] if args.key?(:metric_name)
  @metric_values = args[:metric_values] if args.key?(:metric_values)
end