Class: Google::Apis::ServicecontrolV1::Oauth

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

This message defines attributes associated with OAuth credentials.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Oauth

Returns a new instance of Oauth.



1492
1493
1494
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1492

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

The optional OAuth client ID. This is the unique public identifier issued by an authorization server to a registered client application. Empty string is equivalent to no oauth client id. WARNING: This is for MCP tools/call and tools/list authorization and not for general use. Corresponds to the JSON property clientId

Returns:

  • (String)


1490
1491
1492
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1490

def client_id
  @client_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1497
1498
1499
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1497

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
end