Class: Google::Apis::ServicecontrolV1::Operation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

Represents information regarding an operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



1602
1603
1604
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1602

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_idString

Identity of the consumer who is using the service. This field should be filled in for the operations initiated by a consumer, but not for service-initiated operations that are not related to a specific consumer. - This can be in one of the following formats: - project:PROJECT_ID, - project_number: PROJECT_NUMBER, - projects/PROJECT_ID or PROJECT_NUMBER, - folders/ FOLDER_NUMBER, - organizations/ORGANIZATION_NUMBER, - api_key:API_KEY. Corresponds to the JSON property consumerId

Returns:

  • (String)


1514
1515
1516
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1514

def consumer_id
  @consumer_id
end

#end_timeString

End time of the operation. Required when the operation is used in ServiceController.Report, but optional when the operation is used in ServiceController.Check. Corresponds to the JSON property endTime

Returns:

  • (String)


1521
1522
1523
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1521

def end_time
  @end_time
end

#importanceString

DO NOT USE. This is an experimental field. Corresponds to the JSON property importance

Returns:

  • (String)


1526
1527
1528
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1526

def importance
  @importance
end

#labelsHash<String,String>

Labels describing the operation. Only the following labels are allowed: - Labels describing monitored resources as defined in the service configuration.

  • Default labels of metric values. When specified, labels defined in the metric value override these default. - The following labels defined by Google Cloud Platform: - cloud.googleapis.com/location describing the location where the operation happened, - servicecontrol.googleapis.com/user_agent describing the user agent of the API request, - servicecontrol.googleapis.com/ service_agent describing the service used to handle the API request (e.g. ESP) , - servicecontrol.googleapis.com/platform describing the platform where the API is served, such as App Engine, Compute Engine, or Kubernetes Engine. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1540
1541
1542
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1540

def labels
  @labels
end

#log_entriesArray<Google::Apis::ServicecontrolV1::LogEntry>

Represents information to be logged. Corresponds to the JSON property logEntries



1545
1546
1547
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1545

def log_entries
  @log_entries
end

#metric_value_setsArray<Google::Apis::ServicecontrolV1::MetricValueSet>

Represents information about this operation. Each MetricValueSet corresponds to a metric defined in the service configuration. The data type used in the MetricValueSet must agree with the data type specified in the metric definition. Within a single operation, it is not allowed to have more than one MetricValue instances that have the same metric names and identical label value combinations. If a request has such duplicated MetricValue instances, the entire request is rejected with an invalid argument error. Corresponds to the JSON property metricValueSets



1556
1557
1558
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1556

def metric_value_sets
  @metric_value_sets
end

#operation_idString

Identity of the operation. This must be unique within the scope of the service that generated the operation. If the service calls Check() and Report() on the same operation, the two calls should carry the same id. UUID version 4 is recommended, though not required. In scenarios where an operation is computed from existing information and an idempotent id is desirable for deduplication purpose, UUID version 5 is recommended. See RFC 4122 for details. Corresponds to the JSON property operationId

Returns:

  • (String)


1566
1567
1568
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1566

def operation_id
  @operation_id
end

#operation_nameString

Fully qualified name of the operation. Reserved for future use. Corresponds to the JSON property operationName

Returns:

  • (String)


1571
1572
1573
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1571

def operation_name
  @operation_name
end

#quota_propertiesGoogle::Apis::ServicecontrolV1::QuotaProperties

Represents the properties needed for quota operations. Corresponds to the JSON property quotaProperties



1576
1577
1578
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1576

def quota_properties
  @quota_properties
end

#resourcesArray<Google::Apis::ServicecontrolV1::ResourceInfo>

The resources that are involved in the operation. The maximum supported number of entries in this field is 100. Corresponds to the JSON property resources



1582
1583
1584
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1582

def resources
  @resources
end

#start_timeString

Required. Start time of the operation. Corresponds to the JSON property startTime

Returns:

  • (String)


1587
1588
1589
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1587

def start_time
  @start_time
end

#trace_spansArray<Google::Apis::ServicecontrolV1::TraceSpan>

Unimplemented. A list of Cloud Trace spans. The span names shall contain the id of the destination project which can be either the produce or the consumer project. Corresponds to the JSON property traceSpans



1594
1595
1596
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1594

def trace_spans
  @trace_spans
end

#user_labelsHash<String,String>

Private Preview. This feature is only available for approved services. User defined labels for the resource that this operation is associated with. Corresponds to the JSON property userLabels

Returns:

  • (Hash<String,String>)


1600
1601
1602
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1600

def user_labels
  @user_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1607

def update!(**args)
  @consumer_id = args[:consumer_id] if args.key?(:consumer_id)
  @end_time = args[:end_time] if args.key?(:end_time)
  @importance = args[:importance] if args.key?(:importance)
  @labels = args[:labels] if args.key?(:labels)
  @log_entries = args[:log_entries] if args.key?(:log_entries)
  @metric_value_sets = args[:metric_value_sets] if args.key?(:metric_value_sets)
  @operation_id = args[:operation_id] if args.key?(:operation_id)
  @operation_name = args[:operation_name] if args.key?(:operation_name)
  @quota_properties = args[:quota_properties] if args.key?(:quota_properties)
  @resources = args[:resources] if args.key?(:resources)
  @start_time = args[:start_time] if args.key?(:start_time)
  @trace_spans = args[:trace_spans] if args.key?(:trace_spans)
  @user_labels = args[:user_labels] if args.key?(:user_labels)
end