Class: Google::Apis::ServicecontrolV1::OrgPolicyViolationInfo
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::OrgPolicyViolationInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
Represents OrgPolicy Violation information.
Instance Attribute Summary collapse
-
#payload ⇒ Hash<String,Object>
Optional.
-
#resource_tags ⇒ Hash<String,String>
Optional.
-
#resource_type ⇒ String
Optional.
-
#violation_info ⇒ Array<Google::Apis::ServicecontrolV1::ViolationInfo>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OrgPolicyViolationInfo
constructor
A new instance of OrgPolicyViolationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OrgPolicyViolationInfo
Returns a new instance of OrgPolicyViolationInfo.
1635 1636 1637 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1635 def initialize(**args) update!(**args) end |
Instance Attribute Details
#payload ⇒ Hash<String,Object>
Optional. Deprecated. Resource payload that is currently in scope and is
subjected to orgpolicy conditions. This payload may be the subset of the
actual Resource that may come in the request.
Corresponds to the JSON property payload
1616 1617 1618 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1616 def payload @payload end |
#resource_tags ⇒ Hash<String,String>
Optional. Deprecated. Tags referenced on the resource at the time of
evaluation.
Corresponds to the JSON property resourceTags
1622 1623 1624 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1622 def @resource_tags end |
#resource_type ⇒ String
Optional. Resource type that the orgpolicy is checked against. Example:
compute.googleapis.com/Instance, store.googleapis.com/bucket
Corresponds to the JSON property resourceType
1628 1629 1630 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1628 def resource_type @resource_type end |
#violation_info ⇒ Array<Google::Apis::ServicecontrolV1::ViolationInfo>
Optional. Policy violations
Corresponds to the JSON property violationInfo
1633 1634 1635 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1633 def violation_info @violation_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1640 1641 1642 1643 1644 1645 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1640 def update!(**args) @payload = args[:payload] if args.key?(:payload) @resource_tags = args[:resource_tags] if args.key?(:resource_tags) @resource_type = args[:resource_type] if args.key?(:resource_type) @violation_info = args[:violation_info] if args.key?(:violation_info) end |