Class: Google::Apis::ServicecontrolV1::QuotaError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

Represents error information for QuotaOperation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotaError

Returns a new instance of QuotaError.



1764
1765
1766
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1764

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Error code. Corresponds to the JSON property code

Returns:

  • (String)


1741
1742
1743
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1741

def code
  @code
end

#descriptionString

Free-form text that provides details on the cause of the error. Corresponds to the JSON property description

Returns:

  • (String)


1746
1747
1748
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1746

def description
  @description
end

#statusGoogle::Apis::ServicecontrolV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



1756
1757
1758
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1756

def status
  @status
end

#subjectString

Subject to whom this error applies. See the specific enum for more details on this field. For example, "clientip:" or "project:". Corresponds to the JSON property subject

Returns:

  • (String)


1762
1763
1764
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1762

def subject
  @subject
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1769
1770
1771
1772
1773
1774
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1769

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @description = args[:description] if args.key?(:description)
  @status = args[:status] if args.key?(:status)
  @subject = args[:subject] if args.key?(:subject)
end