Class: Google::Apis::ServicecontrolV1::QuotaInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

Contains the quota information for a quota check response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotaInfo

Returns a new instance of QuotaInfo.



1817
1818
1819
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1817

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#limit_exceededArray<String>

Quota Metrics that have exceeded quota limits. For QuotaGroup-based quota, this is QuotaGroup.name For QuotaLimit-based quota, this is QuotaLimit.name See: google.api.Quota Deprecated: Use quota_metrics to get per quota group limit exceeded status. Corresponds to the JSON property limitExceeded

Returns:

  • (Array<String>)


1787
1788
1789
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1787

def limit_exceeded
  @limit_exceeded
end

#quota_consumedHash<String,Fixnum>

Map of quota group name to the actual number of tokens consumed. If the quota check was not successful, then this will not be populated due to no quota consumption. We are not merging this field with 'quota_metrics' field because of the complexity of scaling in Chemist client code base. For simplicity, we will keep this field for Castor (that scales quota usage) and 'quota_metrics' for SuperQuota (that doesn't scale quota usage). Corresponds to the JSON property quotaConsumed

Returns:

  • (Hash<String,Fixnum>)


1797
1798
1799
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1797

def quota_consumed
  @quota_consumed
end

#quota_extraction_stateString

Output only. Indicates the state of the quota extraction. Corresponds to the JSON property quotaExtractionState

Returns:

  • (String)


1802
1803
1804
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1802

def quota_extraction_state
  @quota_extraction_state
end

#quota_metricsArray<Google::Apis::ServicecontrolV1::MetricValueSet>

Quota metrics to indicate the usage. Depending on the check request, one or more of the following metrics will be included: 1. For rate quota, per quota group or per quota metric incremental usage will be specified using the following delta metric: "serviceruntime.googleapis.com/api/consumer/ quota_used_count" 2. For allocation quota, per quota metric total usage will be specified using the following gauge metric: "serviceruntime.googleapis.com/ allocation/consumer/quota_used_count" 3. For both rate quota and allocation quota, the quota limit reached condition will be specified using the following boolean metric: "serviceruntime.googleapis.com/quota/exceeded" Corresponds to the JSON property quotaMetrics



1815
1816
1817
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1815

def quota_metrics
  @quota_metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1822
1823
1824
1825
1826
1827
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1822

def update!(**args)
  @limit_exceeded = args[:limit_exceeded] if args.key?(:limit_exceeded)
  @quota_consumed = args[:quota_consumed] if args.key?(:quota_consumed)
  @quota_extraction_state = args[:quota_extraction_state] if args.key?(:quota_extraction_state)
  @quota_metrics = args[:quota_metrics] if args.key?(:quota_metrics)
end