Class: Google::Apis::ServicecontrolV1::ReportError
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::ReportError
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
Represents the processing error of one Operation in the request.
Instance Attribute Summary collapse
-
#operation_id ⇒ String
The Operation.operation_id value from the request.
-
#status ⇒ Google::Apis::ServicecontrolV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportError
constructor
A new instance of ReportError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportError
Returns a new instance of ReportError.
2034 2035 2036 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2034 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operation_id ⇒ String
The Operation.operation_id value from the request.
Corresponds to the JSON property operationId
2022 2023 2024 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2022 def operation_id @operation_id end |
#status ⇒ Google::Apis::ServicecontrolV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
2032 2033 2034 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2032 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2039 2040 2041 2042 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2039 def update!(**args) @operation_id = args[:operation_id] if args.key?(:operation_id) @status = args[:status] if args.key?(:status) end |