Class: Google::Apis::ServicecontrolV1::ReportError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

Represents the processing error of one Operation in the request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportError

Returns a new instance of ReportError.



1921
1922
1923
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operation_idString

The Operation.operation_id value from the request. Corresponds to the JSON property operationId

Returns:

  • (String)


1909
1910
1911
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1909

def operation_id
  @operation_id
end

#statusGoogle::Apis::ServicecontrolV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



1919
1920
1921
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1919

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1926
1927
1928
1929
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1926

def update!(**args)
  @operation_id = args[:operation_id] if args.key?(:operation_id)
  @status = args[:status] if args.key?(:status)
end