Class: Google::Apis::ServicecontrolV1::ReportRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

Request message for the Report method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportRequest

Returns a new instance of ReportRequest.



1970
1971
1972
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1970

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::ServicecontrolV1::Operation>

Operations to be reported. Typically the service should report one operation per request. Putting multiple operations into a single request is allowed, but should be used only when multiple operations are natually available at the time of the report. There is no limit on the number of operations in the same ReportRequest, however the ReportRequest size should be no larger than 1MB. See ReportResponse.report_errors for partial failure behavior. Corresponds to the JSON property operations



1961
1962
1963
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1961

def operations
  @operations
end

#service_config_idString

Specifies which version of service config should be used to process the request. If unspecified or no matching version can be found, the latest one will be used. Corresponds to the JSON property serviceConfigId

Returns:

  • (String)


1968
1969
1970
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1968

def service_config_id
  @service_config_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1975
1976
1977
1978
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 1975

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @service_config_id = args[:service_config_id] if args.key?(:service_config_id)
end