Class: Google::Apis::ServicecontrolV1::Request

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

This message defines attributes for an HTTP request. If the actual request is not an HTTP request, the runtime system should try to map the actual request to an equivalent HTTP request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Request

Returns a new instance of Request.



2098
2099
2100
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2098

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authGoogle::Apis::ServicecontrolV1::Auth

This message defines request authentication attributes. Terminology is based on the JSON Web Token (JWT) standard, but the terms also correlate to concepts in other standards. Corresponds to the JSON property auth



2024
2025
2026
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2024

def auth
  @auth
end

#headersHash<String,String>

The HTTP request headers. If multiple headers share the same key, they must be merged according to the HTTP spec. All header keys must be lowercased, because HTTP header keys are case-insensitive. Corresponds to the JSON property headers

Returns:

  • (Hash<String,String>)


2031
2032
2033
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2031

def headers
  @headers
end

#hostString

The HTTP request Host header value. Corresponds to the JSON property host

Returns:

  • (String)


2036
2037
2038
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2036

def host
  @host
end

#idString

The unique ID for a request, which can be propagated to downstream systems. The ID should have low probability of collision within a single day for a specific service. Corresponds to the JSON property id

Returns:

  • (String)


2043
2044
2045
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2043

def id
  @id
end

#method_propString

The HTTP request method, such as GET, POST. Corresponds to the JSON property method

Returns:

  • (String)


2048
2049
2050
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2048

def method_prop
  @method_prop
end

#originString

The values from Origin header from the HTTP request, such as "https://console. cloud.google.com". Modern browsers can only have one origin. Special browsers and/or HTTP clients may require multiple origins. Corresponds to the JSON property origin

Returns:

  • (String)


2055
2056
2057
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2055

def origin
  @origin
end

#pathString

The HTTP URL path, excluding the query parameters. Corresponds to the JSON property path

Returns:

  • (String)


2060
2061
2062
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2060

def path
  @path
end

#protocolString

The network protocol used with the request, such as "http/1.1", "spdy/3", "h2", "h2c", "webrtc", "tcp", "udp", "quic". See https://www.iana.org/assignments/ tls-extensiontype-values/tls-extensiontype-values.xhtml#alpn-protocol-ids for details. Corresponds to the JSON property protocol

Returns:

  • (String)


2068
2069
2070
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2068

def protocol
  @protocol
end

#queryString

The HTTP URL query in the format of name1=value1&name2=value2, as it appears in the first line of the HTTP request. No decoding is performed. Corresponds to the JSON property query

Returns:

  • (String)


2074
2075
2076
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2074

def query
  @query
end

#reasonString

A special parameter for request reason. It is used by security systems to associate auditing information with a request. Corresponds to the JSON property reason

Returns:

  • (String)


2080
2081
2082
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2080

def reason
  @reason
end

#schemeString

The HTTP URL scheme, such as http and https. Corresponds to the JSON property scheme

Returns:

  • (String)


2085
2086
2087
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2085

def scheme
  @scheme
end

#sizeFixnum

The HTTP request size in bytes. If unknown, it must be -1. Corresponds to the JSON property size

Returns:

  • (Fixnum)


2090
2091
2092
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2090

def size
  @size
end

#timeString

The timestamp when the destination service receives the last byte of the request. Corresponds to the JSON property time

Returns:

  • (String)


2096
2097
2098
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2096

def time
  @time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2103

def update!(**args)
  @auth = args[:auth] if args.key?(:auth)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @id = args[:id] if args.key?(:id)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @origin = args[:origin] if args.key?(:origin)
  @path = args[:path] if args.key?(:path)
  @protocol = args[:protocol] if args.key?(:protocol)
  @query = args[:query] if args.key?(:query)
  @reason = args[:reason] if args.key?(:reason)
  @scheme = args[:scheme] if args.key?(:scheme)
  @size = args[:size] if args.key?(:size)
  @time = args[:time] if args.key?(:time)
end