Class: Google::Apis::ServicecontrolV1::Request

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

This message defines attributes for an HTTP request. If the actual request is not an HTTP request, the runtime system should try to map the actual request to an equivalent HTTP request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Request

Returns a new instance of Request.



2089
2090
2091
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2089

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authGoogle::Apis::ServicecontrolV1::Auth

This message defines request authentication attributes. Terminology is based on the JSON Web Token (JWT) standard, but the terms also correlate to concepts in other standards. Corresponds to the JSON property auth



2015
2016
2017
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2015

def auth
  @auth
end

#headersHash<String,String>

The HTTP request headers. If multiple headers share the same key, they must be merged according to the HTTP spec. All header keys must be lowercased, because HTTP header keys are case-insensitive. Corresponds to the JSON property headers

Returns:

  • (Hash<String,String>)


2022
2023
2024
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2022

def headers
  @headers
end

#hostString

The HTTP request Host header value. Corresponds to the JSON property host

Returns:

  • (String)


2027
2028
2029
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2027

def host
  @host
end

#idString

The unique ID for a request, which can be propagated to downstream systems. The ID should have low probability of collision within a single day for a specific service. Corresponds to the JSON property id

Returns:

  • (String)


2034
2035
2036
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2034

def id
  @id
end

#method_propString

The HTTP request method, such as GET, POST. Corresponds to the JSON property method

Returns:

  • (String)


2039
2040
2041
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2039

def method_prop
  @method_prop
end

#originString

The values from Origin header from the HTTP request, such as "https://console. cloud.google.com". Modern browsers can only have one origin. Special browsers and/or HTTP clients may require multiple origins. Corresponds to the JSON property origin

Returns:

  • (String)


2046
2047
2048
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2046

def origin
  @origin
end

#pathString

The HTTP URL path, excluding the query parameters. Corresponds to the JSON property path

Returns:

  • (String)


2051
2052
2053
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2051

def path
  @path
end

#protocolString

The network protocol used with the request, such as "http/1.1", "spdy/3", "h2", "h2c", "webrtc", "tcp", "udp", "quic". See https://www.iana.org/assignments/ tls-extensiontype-values/tls-extensiontype-values.xhtml#alpn-protocol-ids for details. Corresponds to the JSON property protocol

Returns:

  • (String)


2059
2060
2061
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2059

def protocol
  @protocol
end

#queryString

The HTTP URL query in the format of name1=value1&name2=value2, as it appears in the first line of the HTTP request. No decoding is performed. Corresponds to the JSON property query

Returns:

  • (String)


2065
2066
2067
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2065

def query
  @query
end

#reasonString

A special parameter for request reason. It is used by security systems to associate auditing information with a request. Corresponds to the JSON property reason

Returns:

  • (String)


2071
2072
2073
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2071

def reason
  @reason
end

#schemeString

The HTTP URL scheme, such as http and https. Corresponds to the JSON property scheme

Returns:

  • (String)


2076
2077
2078
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2076

def scheme
  @scheme
end

#sizeFixnum

The HTTP request size in bytes. If unknown, it must be -1. Corresponds to the JSON property size

Returns:

  • (Fixnum)


2081
2082
2083
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2081

def size
  @size
end

#timeString

The timestamp when the destination service receives the last byte of the request. Corresponds to the JSON property time

Returns:

  • (String)


2087
2088
2089
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2087

def time
  @time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2094

def update!(**args)
  @auth = args[:auth] if args.key?(:auth)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @id = args[:id] if args.key?(:id)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @origin = args[:origin] if args.key?(:origin)
  @path = args[:path] if args.key?(:path)
  @protocol = args[:protocol] if args.key?(:protocol)
  @query = args[:query] if args.key?(:query)
  @reason = args[:reason] if args.key?(:reason)
  @scheme = args[:scheme] if args.key?(:scheme)
  @size = args[:size] if args.key?(:size)
  @time = args[:time] if args.key?(:time)
end