Class: Google::Apis::ServicecontrolV1::ServiceDelegationHistory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

The history of delegation across multiple services as the result of the original user's action. Such as "service A uses its own account to do something for user B". This differs from ServiceAccountDelegationInfo, which only tracks the history of direct token exchanges (impersonation).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceDelegationHistory

Returns a new instance of ServiceDelegationHistory.



2414
2415
2416
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2414

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#original_principalString

The original end user who initiated the request to GCP. Corresponds to the JSON property originalPrincipal

Returns:

  • (String)


2406
2407
2408
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2406

def original_principal
  @original_principal
end

#service_metadataArray<Google::Apis::ServicecontrolV1::ServiceMetadata>

Data identifying the service specific jobs or units of work that were involved in a chain of service calls. Corresponds to the JSON property serviceMetadata



2412
2413
2414
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2412

def 
  @service_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2419
2420
2421
2422
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2419

def update!(**args)
  @original_principal = args[:original_principal] if args.key?(:original_principal)
  @service_metadata = args[:service_metadata] if args.key?(:service_metadata)
end