Class: Google::Apis::ServicecontrolV1::V1HttpRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::V1HttpRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
A common proto for logging HTTP requests. Only contains semantics defined by the HTTP specification. Product-specific logging information MUST be defined in a separate message.
Instance Attribute Summary collapse
-
#cache_fill_bytes ⇒ Fixnum
The number of HTTP response bytes inserted into cache.
-
#cache_hit ⇒ Boolean
(also: #cache_hit?)
Whether or not an entity was served from cache (with or without validation).
-
#cache_lookup ⇒ Boolean
(also: #cache_lookup?)
Whether or not a cache lookup was attempted.
-
#cache_validated_with_origin_server ⇒ Boolean
(also: #cache_validated_with_origin_server?)
Whether or not the response was validated with the origin server before being served from cache.
-
#latency ⇒ String
The request processing latency on the server, from the time the request was received until the response was sent.
-
#protocol ⇒ String
Protocol used for the request.
-
#referer ⇒ String
The referer URL of the request, as defined in HTTP/1.1 Header Field Definitions.
-
#remote_ip ⇒ String
The IP address (IPv4 or IPv6) of the client that issued the HTTP request.
-
#request_method ⇒ String
The request method.
-
#request_size ⇒ Fixnum
The size of the HTTP request message in bytes, including the request headers and the request body.
-
#request_url ⇒ String
The scheme (http, https), the host name, the path, and the query portion of the URL that was requested.
-
#response_size ⇒ Fixnum
The size of the HTTP response message sent back to the client, in bytes, including the response headers and the response body.
-
#server_ip ⇒ String
The IP address (IPv4 or IPv6) of the origin server that the request was sent to.
-
#status ⇒ Fixnum
The response code indicating the status of the response.
-
#user_agent ⇒ String
The user agent sent by the client.
Instance Method Summary collapse
-
#initialize(**args) ⇒ V1HttpRequest
constructor
A new instance of V1HttpRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ V1HttpRequest
Returns a new instance of V1HttpRequest.
2800 2801 2802 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2800 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cache_fill_bytes ⇒ Fixnum
The number of HTTP response bytes inserted into cache. Set only when a cache
fill was attempted.
Corresponds to the JSON property cacheFillBytes
2715 2716 2717 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2715 def cache_fill_bytes @cache_fill_bytes end |
#cache_hit ⇒ Boolean Also known as: cache_hit?
Whether or not an entity was served from cache (with or without validation).
Corresponds to the JSON property cacheHit
2720 2721 2722 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2720 def cache_hit @cache_hit end |
#cache_lookup ⇒ Boolean Also known as: cache_lookup?
Whether or not a cache lookup was attempted.
Corresponds to the JSON property cacheLookup
2726 2727 2728 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2726 def cache_lookup @cache_lookup end |
#cache_validated_with_origin_server ⇒ Boolean Also known as: cache_validated_with_origin_server?
Whether or not the response was validated with the origin server before being
served from cache. This field is only meaningful if cache_hit is True.
Corresponds to the JSON property cacheValidatedWithOriginServer
2733 2734 2735 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2733 def cache_validated_with_origin_server @cache_validated_with_origin_server end |
#latency ⇒ String
The request processing latency on the server, from the time the request was
received until the response was sent.
Corresponds to the JSON property latency
2740 2741 2742 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2740 def latency @latency end |
#protocol ⇒ String
Protocol used for the request. Examples: "HTTP/1.1", "HTTP/2", "websocket"
Corresponds to the JSON property protocol
2745 2746 2747 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2745 def protocol @protocol end |
#referer ⇒ String
The referer URL of the request, as defined in HTTP/1.1 Header Field
Definitions.
Corresponds to the JSON property referer
2751 2752 2753 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2751 def referer @referer end |
#remote_ip ⇒ String
The IP address (IPv4 or IPv6) of the client that issued the HTTP request.
Examples: "192.168.1.1", "FE80::0202:B3FF:FE1E:8329".
Corresponds to the JSON property remoteIp
2757 2758 2759 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2757 def remote_ip @remote_ip end |
#request_method ⇒ String
The request method. Examples: "GET", "HEAD", "PUT", "POST".
Corresponds to the JSON property requestMethod
2762 2763 2764 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2762 def request_method @request_method end |
#request_size ⇒ Fixnum
The size of the HTTP request message in bytes, including the request headers
and the request body.
Corresponds to the JSON property requestSize
2768 2769 2770 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2768 def request_size @request_size end |
#request_url ⇒ String
The scheme (http, https), the host name, the path, and the query portion of
the URL that was requested. Example: "http://example.com/some/info?color=red"
.
Corresponds to the JSON property requestUrl
2775 2776 2777 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2775 def request_url @request_url end |
#response_size ⇒ Fixnum
The size of the HTTP response message sent back to the client, in bytes,
including the response headers and the response body.
Corresponds to the JSON property responseSize
2781 2782 2783 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2781 def response_size @response_size end |
#server_ip ⇒ String
The IP address (IPv4 or IPv6) of the origin server that the request was sent
to.
Corresponds to the JSON property serverIp
2787 2788 2789 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2787 def server_ip @server_ip end |
#status ⇒ Fixnum
The response code indicating the status of the response. Examples: 200, 404.
Corresponds to the JSON property status
2792 2793 2794 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2792 def status @status end |
#user_agent ⇒ String
The user agent sent by the client. Example: "Mozilla/4.0 (compatible; MSIE 6.
0; Windows 98; Q312461; .NET CLR 1.0.3705)".
Corresponds to the JSON property userAgent
2798 2799 2800 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2798 def user_agent @user_agent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2805 def update!(**args) @cache_fill_bytes = args[:cache_fill_bytes] if args.key?(:cache_fill_bytes) @cache_hit = args[:cache_hit] if args.key?(:cache_hit) @cache_lookup = args[:cache_lookup] if args.key?(:cache_lookup) @cache_validated_with_origin_server = args[:cache_validated_with_origin_server] if args.key?(:cache_validated_with_origin_server) @latency = args[:latency] if args.key?(:latency) @protocol = args[:protocol] if args.key?(:protocol) @referer = args[:referer] if args.key?(:referer) @remote_ip = args[:remote_ip] if args.key?(:remote_ip) @request_method = args[:request_method] if args.key?(:request_method) @request_size = args[:request_size] if args.key?(:request_size) @request_url = args[:request_url] if args.key?(:request_url) @response_size = args[:response_size] if args.key?(:response_size) @server_ip = args[:server_ip] if args.key?(:server_ip) @status = args[:status] if args.key?(:status) @user_agent = args[:user_agent] if args.key?(:user_agent) end |