Class: Google::Apis::ServicecontrolV1::V1LogEntrySourceLocation
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::V1LogEntrySourceLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
Additional information about the source code location that produced the log entry.
Instance Attribute Summary collapse
-
#file ⇒ String
Optional.
-
#function ⇒ String
Optional.
-
#line ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ V1LogEntrySourceLocation
constructor
A new instance of V1LogEntrySourceLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ V1LogEntrySourceLocation
Returns a new instance of V1LogEntrySourceLocation.
2975 2976 2977 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2975 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file ⇒ String
Optional. Source file name. Depending on the runtime environment, this might
be a simple name or a fully-qualified name.
Corresponds to the JSON property file
2958 2959 2960 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2958 def file @file end |
#function ⇒ String
Optional. Human-readable name of the function or method being invoked, with
optional context such as the class or package name. This information may be
used in contexts such as the logs viewer, where a file and line number are
less meaningful. The format can vary by language. For example: qual.if.ied.
Class.method (Java), dir/package.func (Go), function (Python).
Corresponds to the JSON property function
2967 2968 2969 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2967 def function @function end |
#line ⇒ Fixnum
Optional. Line within the source file. 1-based; 0 indicates no line number
available.
Corresponds to the JSON property line
2973 2974 2975 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2973 def line @line end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2980 2981 2982 2983 2984 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 2980 def update!(**args) @file = args[:file] if args.key?(:file) @function = args[:function] if args.key?(:function) @line = args[:line] if args.key?(:line) end |