Class: Google::Apis::ServicecontrolV1::V1ResourceEvent
- Inherits:
-
Object
- Object
- Google::Apis::ServicecontrolV1::V1ResourceEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb
Overview
Report v2 extension proto for passing the resource metadata associated with a resource create/update/delete/undelete event from ESF to Chemist. ResourceEvent proto should be serialized into the ReportRequest.operations. extensions.
Instance Attribute Summary collapse
-
#context_id ⇒ Fixnum
The ESF unique context id of the api request, from which this resource event originated.
-
#destinations ⇒ String
The destinations field determines which backend services should handle the event.
-
#parent ⇒ Google::Apis::ServicecontrolV1::Resource
This message defines core attributes for a resource.
-
#path ⇒ String
The api path the resource event was created in.
-
#payload ⇒ Hash<String,Object>
The payload contains metadata associated with the resource event.
-
#resource ⇒ Google::Apis::ServicecontrolV1::Resource
This message defines core attributes for a resource.
-
#type ⇒ String
The resource event type determines how the backend service should process the event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ V1ResourceEvent
constructor
A new instance of V1ResourceEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ V1ResourceEvent
Returns a new instance of V1ResourceEvent.
3064 3065 3066 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3064 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context_id ⇒ Fixnum
The ESF unique context id of the api request, from which this resource event
originated. This field is only needed for CAIS integration via api annotation.
See go/cais-lro-delete for more details.
Corresponds to the JSON property contextId
3022 3023 3024 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3022 def context_id @context_id end |
#destinations ⇒ String
The destinations field determines which backend services should handle the
event. This should be specified as a comma-delimited string.
Corresponds to the JSON property destinations
3028 3029 3030 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3028 def destinations @destinations end |
#parent ⇒ Google::Apis::ServicecontrolV1::Resource
This message defines core attributes for a resource. A resource is an
addressable (named) entity provided by the destination service. For example, a
file stored on a network storage service.
Corresponds to the JSON property parent
3035 3036 3037 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3035 def parent @parent end |
#path ⇒ String
The api path the resource event was created in. This should match the source
of the payload field. For direct integrations with Chemist, this should
generally be the RESPONSE. go/resource-event-pipeline-type
Corresponds to the JSON property path
3042 3043 3044 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3042 def path @path end |
#payload ⇒ Hash<String,Object>
The payload contains metadata associated with the resource event. A
ResourceEventPayloadStatus is provided instead if the original payload cannot
be returned due to a limitation (e.g. size limit).
Corresponds to the JSON property payload
3049 3050 3051 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3049 def payload @payload end |
#resource ⇒ Google::Apis::ServicecontrolV1::Resource
This message defines core attributes for a resource. A resource is an
addressable (named) entity provided by the destination service. For example, a
file stored on a network storage service.
Corresponds to the JSON property resource
3056 3057 3058 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3056 def resource @resource end |
#type ⇒ String
The resource event type determines how the backend service should process the
event.
Corresponds to the JSON property type
3062 3063 3064 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3062 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3069 3070 3071 3072 3073 3074 3075 3076 3077 |
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3069 def update!(**args) @context_id = args[:context_id] if args.key?(:context_id) @destinations = args[:destinations] if args.key?(:destinations) @parent = args[:parent] if args.key?(:parent) @path = args[:path] if args.key?(:path) @payload = args[:payload] if args.key?(:payload) @resource = args[:resource] if args.key?(:resource) @type = args[:type] if args.key?(:type) end |