Class: Google::Apis::ServicecontrolV1::ViolationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicecontrol_v1/classes.rb,
lib/google/apis/servicecontrol_v1/representations.rb,
lib/google/apis/servicecontrol_v1/representations.rb

Overview

Provides information about the Policy violation info for this request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ViolationInfo

Returns a new instance of ViolationInfo.



3096
3097
3098
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checked_valueString

Optional. Value that is being checked for the policy. This could be in encrypted form (if pii sensitive). This field will only be emitted in LIST_POLICY types Corresponds to the JSON property checkedValue

Returns:

  • (String)


3072
3073
3074
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3072

def checked_value
  @checked_value
end

#constraintString

Optional. Constraint name Corresponds to the JSON property constraint

Returns:

  • (String)


3077
3078
3079
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3077

def constraint
  @constraint
end

#constraint_violation_infoHash<String,Object>

Optional. Provides extra information for the specific violated constraint. See the constraint's documentation to determine if this field is populated and what the structure of the message should be. Corresponds to the JSON property constraintViolationInfo

Returns:

  • (Hash<String,Object>)


3084
3085
3086
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3084

def constraint_violation_info
  @constraint_violation_info
end

#error_messageString

Optional. Error message that policy is indicating. Corresponds to the JSON property errorMessage

Returns:

  • (String)


3089
3090
3091
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3089

def error_message
  @error_message
end

#policy_typeString

Optional. Indicates the type of the policy. Corresponds to the JSON property policyType

Returns:

  • (String)


3094
3095
3096
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3094

def policy_type
  @policy_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3101
3102
3103
3104
3105
3106
3107
# File 'lib/google/apis/servicecontrol_v1/classes.rb', line 3101

def update!(**args)
  @checked_value = args[:checked_value] if args.key?(:checked_value)
  @constraint = args[:constraint] if args.key?(:constraint)
  @constraint_violation_info = args[:constraint_violation_info] if args.key?(:constraint_violation_info)
  @error_message = args[:error_message] if args.key?(:error_message)
  @policy_type = args[:policy_type] if args.key?(:policy_type)
end